==> sober-woocommerce-wordpress-theme3.5.11(www.persianscript.ir).zip: sober/inc/frontend/breadcrumbs.php <==
<?php
/**
 * Display breadcrumbs for posts, pages, archive page with the microdata that search engines understand
 *
 * @see http://support.google.com/webmasters/bin/answer.py?hl=en&answer=185417
 *
 * @param array|string $args
 */
function sober_breadcrumbs( $args = '' ) {
	$args = wp_parse_args( $args, array(
		'separator'         => '<i class="fa fa-angle-right" aria-hidden="true"></i>',
		'home_class'        => 'home',
		'before'            => '<nav class="breadcrumb" itemscope itemtype="https://schema.org/BreadcrumbList">',
		'after'             => '</nav>',
		'before_item'       => '',
		'after_item'        => '',
		'taxonomy'          => 'category',
		'display_last_item' => true,
		'show_on_front'     => false,
		'labels'            => array(
			'home'      => esc_html__( 'Home', 'sober' ),
			'archive'   => esc_html__( 'Archives', 'sober' ),
			'blog'      => esc_html__( 'Blog', 'sober' ),
			'search'    => esc_html__( 'Search results for', 'sober' ),
			'not_found' => esc_html__( 'Not Found', 'sober' ),
			'author'    => esc_html__( 'Author Archives:', 'sober' ),
			'day'       => esc_html__( 'Daily Archives:', 'sober' ),
			'month'     => esc_html__( 'Monthly Archives:', 'sober' ),
			'year'      => esc_html__( 'Yearly Archives:', 'sober' ),
		),
	) );

	$args = apply_filters( 'sober_breadcrumbs_args', $args );

	if ( is_front_page() && ! $args['show_on_front'] ) {
		return;
	}

	$items    = array();
	$position = 1;

	// HTML template for each item
	$item_tpl      = $args['before_item'] . '
		<span itemscope itemtype="https://schema.org/ListItem" itemprop="itemListElement">
			<a href="%s" itemprop="item"><span itemprop="name">%s</span></a>
			<meta itemprop="position" content="%d" />
		</span>' . $args['after_item'];
	$item_text_tpl = $args['before_item'] . '
		<span itemscope itemtype="https://schema.org/ListItem" itemprop="itemListElement">
			<span itemprop="name">%s</span>
			<meta itemprop="position" content="%d" />
		</span>' . $args['after_item'];

	// Home
	if ( ! $args['home_class'] ) {
		$items[] = sprintf( $item_tpl, get_home_url(), $args['labels']['home'], $position++ );
	} else {
		$items[] = sprintf(
			'%s<span class="%s" itemscope itemtype="https://schema.org/ListItem" itemprop="itemListElement">
				<a href="%s" itemprop="item"><span itemprop="name">%s</span></a>
				<meta itemprop="position" content="%d" />
			</span>%s',
			$args['before_item'],
			$args['home_class'],
			get_home_url(),
			$args['labels']['home'],
			$position++,
			$args['after_item']
		);
	}

	// Front page
	if ( is_front_page() ) {
		$items   = array();
		$position = 1;
		$items[] = sprintf( $item_text_tpl, $args['labels']['home'], $position++ );
	} // Blog
	elseif ( is_home() && ! is_front_page() ) {
		$items[] = sprintf(
			$item_text_tpl,
			$args['labels']['blog'],
			$position++
		);
	} // Single
	elseif ( is_single() ) {
		if ( 'post' == get_post_type( get_the_ID() ) && 'page' == get_option( 'show_on_front' ) && ( $blog_page_id = get_option( 'page_for_posts' ) ) ) {
			$items[] = sprintf( $item_tpl, get_page_link( $blog_page_id ), get_the_title( $blog_page_id ), $position++ );
		}

		// Terms
		$taxonomy = $args['taxonomy'];
		$terms    = get_the_terms( get_the_ID(), $taxonomy );

		if ( $terms ) {
			$term    = current( $terms );
			$terms   = sober_get_term_parents( $term->term_id, $taxonomy );
			$terms[] = $term->term_id;

			foreach ( $terms as $term_id ) {
				$term    = get_term( $term_id, $taxonomy );
				$items[] = sprintf( $item_tpl, get_term_link( $term, $taxonomy ), $term->name, $position++ );
			}
		}

		if ( $args['display_last_item'] ) {
			$items[] = sprintf( $item_text_tpl, get_the_title(), $position++ );
		}
	} // Page
	elseif ( is_page() ) {
		$pages = sober_get_post_parents( get_queried_object_id() );
		foreach ( $pages as $page ) {
			$items[] = sprintf( $item_tpl, get_permalink( $page ), get_the_title( $page ), $position++ );
		}
		if ( $args['display_last_item'] ) {
			$items[] = sprintf( $item_text_tpl, get_the_title(), $position++ );
		}
	} // Taxonomy
	elseif ( is_tax() || is_category() || is_tag() ) {
		$current_term = get_queried_object();

		if ( $current_term ) {
			if ( 'category' == $current_term->taxonomy && 'page' == get_option( 'show_on_front' ) && ( $blog_page_id = get_option( 'page_for_posts' ) ) ) {
				$items[] = sprintf( $item_tpl, get_page_link( $blog_page_id ), get_the_title( $blog_page_id ), $position++ );
			}

			if ( is_object_in_taxonomy( 'portfolio', $current_term->taxonomy ) && ( $portfolio_page_id = get_option( 'sober_portfolio_page_id' ) ) ) {
				$items[] = sprintf( $item_tpl, get_page_link( $portfolio_page_id ), get_the_title( $portfolio_page_id ), $position++ );
			}

			$terms = sober_get_term_parents( get_queried_object_id(), $current_term->taxonomy );
			if ( $terms ) {
				foreach ( $terms as $term_id ) {
					$term    = get_term( $term_id, $current_term->taxonomy );
					$items[] = sprintf( $item_tpl, get_category_link( $term_id ), $term->name, $position++ );
				}
			}

			if ( $args['display_last_item'] ) {
				$items[] = sprintf( $item_text_tpl, $current_term->name, $position++ );
			}
		}

	} // Search
	elseif ( is_search() ) {
		$items[] = sprintf( $item_text_tpl, $args['labels']['search'] . ' &quot;' . get_search_query() . '&quot;', $position++ );
	} // 404
	elseif ( is_404() ) {
		$items[] = sprintf( $item_text_tpl, $args['labels']['not_found'], $position++ );
	} // Author archive
	elseif ( is_author() ) {
		// Queue the first post, that way we know what author we're dealing with (if that is the case).
		the_post();
		$items[] = sprintf(
			$item_text_tpl,
			$args['labels']['author'] . ' <span class="vcard"><a class="url fn n" href="' . get_author_posts_url( get_the_author_meta( 'ID' ) ) . '" title="' . esc_attr( get_the_author() ) . '" rel="me">' . get_the_author() . '</a></span>',
			$position++
		);
		rewind_posts();
	} // Day archive
	elseif ( is_day() ) {
		$items[] = sprintf(
			$item_text_tpl,
			sprintf( esc_html( '%s %s' ), $args['labels']['day'], get_the_date() ),
			$position++
		);
	} // Month archive
	elseif ( is_month() ) {
		$items[] = sprintf(
			$item_text_tpl,
			sprintf( esc_html( '%s %s' ), $args['labels']['month'], get_the_date( 'F Y' ) ),
			$position++
		);
	} // Year archive
	elseif ( is_year() ) {
		$items[] = sprintf(
			$item_text_tpl,
			sprintf( esc_html( '%s %s' ), $args['labels']['year'], get_the_date( 'Y' ) ),
			$position++
		);
	} // Archive
	else {
		$items[] = sprintf(
			$item_text_tpl,
			$args['labels']['archive'],
			$position++
		);
	}

	echo trim( $args['before'] ) . implode( $args['separator'], $items ) . trim( $args['after'] );
}

/**
 * Searches for term parents' IDs of hierarchical taxonomies, including current term.
 * This function is similar to the WordPress function get_category_parents() but handles any type of taxonomy.
 * Modified from Hybrid Framework
 *
 * @param int|string    $term_id  The term ID
 * @param object|string $taxonomy The taxonomy of the term whose parents we want.
 *
 * @return array Array of parent terms' IDs.
 */
function sober_get_term_parents( $term_id = '', $taxonomy = 'category' ) {
	// Set up some default arrays.
	$list = array();

	// If no term ID or taxonomy is given, return an empty array.
	if ( empty( $term_id ) || empty( $taxonomy ) ) {
		return $list;
	}

	do {
		$list[] = $term_id;

		// Get next parent term
		$term    = get_term( $term_id, $taxonomy );
		$term_id = $term->parent;
	} while ( $term_id );

	// Reverse the array to put them in the proper order for the trail.
	$list = array_reverse( $list );
	array_pop( $list );

	return $list;
}

/**
 * Gets parent posts' IDs of any post type, include current post
 * Modified from Hybrid Framework
 *
 * @param int|string $post_id ID of the post whose parents we want.
 *
 * @return array Array of parent posts' IDs.
 */
function sober_get_post_parents( $post_id = '' ) {
	// Set up some default array.
	$list = array();

	// If no post ID is given, return an empty array.
	if ( empty( $post_id ) ) {
		return $list;
	}

	do {
		$list[] = $post_id;

		// Get next parent post
		$post    = get_post( $post_id );
		$post_id = $post->post_parent;
	} while ( $post_id );

	// Reverse the array to put them in the proper order for the trail.
	$list = array_reverse( $list );
	array_pop( $list );

	return $list;
}

==> sober-woocommerce-wordpress-theme3.6.1(www.persianscript.ir).zip: sober/inc/frontend/breadcrumbs.php <==
<?php
/**
 * Frontend breadcrumbs functions
 *
 * @package Sober
 */

/**
 * Display breadcrumbs for posts, pages, archive page with the microdata that search engines understand
 *
 * @see http://support.google.com/webmasters/bin/answer.py?hl=en&answer=185417
 *
 * @param array|string $args Arguments for customizing the breadcrumbs display.
 */
function sober_breadcrumbs( $args = '' ) {
	$args = wp_parse_args(
		$args,
		array(
			'separator'         => '<i class="fa fa-angle-right" aria-hidden="true"></i>',
			'home_class'        => 'home',
			'before'            => '<nav class="breadcrumb" itemscope itemtype="https://schema.org/BreadcrumbList">',
			'after'             => '</nav>',
			'before_item'       => '',
			'after_item'        => '',
			'taxonomy'          => 'category',
			'display_last_item' => true,
			'show_on_front'     => false,
			'labels'            => array(
				'home'      => esc_html__( 'Home', 'sober' ),
				'archive'   => esc_html__( 'Archives', 'sober' ),
				'blog'      => esc_html__( 'Blog', 'sober' ),
				'search'    => esc_html__( 'Search results for', 'sober' ),
				'not_found' => esc_html__( 'Not Found', 'sober' ),
				'author'    => esc_html__( 'Author Archives:', 'sober' ),
				'day'       => esc_html__( 'Daily Archives:', 'sober' ),
				'month'     => esc_html__( 'Monthly Archives:', 'sober' ),
				'year'      => esc_html__( 'Yearly Archives:', 'sober' ),
			),
		)
	);

	$args = apply_filters( 'sober_breadcrumbs_args', $args );

	if ( is_front_page() && ! $args['show_on_front'] ) {
		return;
	}

	$items    = array();
	$position = 1;

	// HTML template for each item.
	$item_tpl      = $args['before_item'] . '
		<span itemscope itemtype="https://schema.org/ListItem" itemprop="itemListElement">
			<a href="%s" itemprop="item"><span itemprop="name">%s</span></a>
			<meta itemprop="position" content="%d" />
		</span>' . $args['after_item'];
	$item_text_tpl = $args['before_item'] . '
		<span itemscope itemtype="https://schema.org/ListItem" itemprop="itemListElement">
			<span itemprop="name">%s</span>
			<meta itemprop="position" content="%d" />
		</span>' . $args['after_item'];

	// Home.
	if ( ! $args['home_class'] ) {
		$items[] = sprintf( $item_tpl, get_home_url(), $args['labels']['home'], $position++ );
	} else {
		$items[] = sprintf(
			'%s<span class="%s" itemscope itemtype="https://schema.org/ListItem" itemprop="itemListElement">
				<a href="%s" itemprop="item"><span itemprop="name">%s</span></a>
				<meta itemprop="position" content="%d" />
			</span>%s',
			$args['before_item'],
			$args['home_class'],
			get_home_url(),
			$args['labels']['home'],
			$position++,
			$args['after_item']
		);
	}

	// Front page.
	if ( is_front_page() ) {
		$items    = array();
		$position = 1;
		$items[]  = sprintf( $item_text_tpl, $args['labels']['home'], $position++ );
	} elseif ( is_home() && ! is_front_page() ) { // Blog.
		$items[] = sprintf(
			$item_text_tpl,
			$args['labels']['blog'],
			$position++
		);
	} elseif ( is_single() ) { // Single.
		// phpcs:ignore
		if ( 'post' == get_post_type( get_the_ID() ) && 'page' == get_option( 'show_on_front' ) && ( $blog_page_id = get_option( 'page_for_posts' ) ) ) {
			$items[] = sprintf( $item_tpl, get_page_link( $blog_page_id ), get_the_title( $blog_page_id ), $position++ );
		}

		$taxonomy = $args['taxonomy'];
		$terms    = get_the_terms( get_the_ID(), $taxonomy );

		if ( $terms ) {
			$term    = current( $terms );
			$terms   = sober_get_term_parents( $term->term_id, $taxonomy );
			$terms[] = $term->term_id;

			foreach ( $terms as $term_id ) {
				$term    = get_term( $term_id, $taxonomy );
				$items[] = sprintf( $item_tpl, get_term_link( $term, $taxonomy ), $term->name, $position++ );
			}
		}

		if ( $args['display_last_item'] ) {
			$items[] = sprintf( $item_text_tpl, get_the_title(), $position++ );
		}
	} elseif ( is_page() ) {
		$pages = sober_get_post_parents( get_queried_object_id() );
		foreach ( $pages as $page ) {
			$items[] = sprintf( $item_tpl, get_permalink( $page ), get_the_title( $page ), $position++ );
		}
		if ( $args['display_last_item'] ) {
			$items[] = sprintf( $item_text_tpl, get_the_title(), $position++ );
		}
	} elseif ( is_tax() || is_category() || is_tag() ) {
		$current_term = get_queried_object();

		if ( $current_term ) {
			// phpcs:ignore
			if ( 'category' == $current_term->taxonomy && 'page' == get_option( 'show_on_front' ) && ( $blog_page_id = get_option( 'page_for_posts' ) ) ) {
				$items[] = sprintf( $item_tpl, get_page_link( $blog_page_id ), get_the_title( $blog_page_id ), $position++ );
			}

			// phpcs:ignore
			if ( is_object_in_taxonomy( 'portfolio', $current_term->taxonomy ) && ( $portfolio_page_id = get_option( 'sober_portfolio_page_id' ) ) ) {
				$items[] = sprintf( $item_tpl, get_page_link( $portfolio_page_id ), get_the_title( $portfolio_page_id ), $position++ );
			}

			$terms = sober_get_term_parents( get_queried_object_id(), $current_term->taxonomy );
			if ( $terms ) {
				foreach ( $terms as $term_id ) {
					$term    = get_term( $term_id, $current_term->taxonomy );
					$items[] = sprintf( $item_tpl, get_category_link( $term_id ), $term->name, $position++ );
				}
			}

			if ( $args['display_last_item'] ) {
				$items[] = sprintf( $item_text_tpl, $current_term->name, $position++ );
			}
		}
	} elseif ( is_search() ) {
		$items[] = sprintf( $item_text_tpl, $args['labels']['search'] . ' &quot;' . get_search_query() . '&quot;', $position++ );
	} elseif ( is_404() ) {
		$items[] = sprintf( $item_text_tpl, $args['labels']['not_found'], $position++ );
	} elseif ( is_author() ) {
		// Queue the first post, that way we know what author we're dealing with (if that is the case).
		the_post();
		$items[] = sprintf(
			$item_text_tpl,
			$args['labels']['author'] . ' <span class="vcard"><a class="url fn n" href="' . get_author_posts_url( get_the_author_meta( 'ID' ) ) . '" title="' . esc_attr( get_the_author() ) . '" rel="me">' . get_the_author() . '</a></span>',
			$position++
		);
		rewind_posts();
	} elseif ( is_day() ) {
		$items[] = sprintf(
			$item_text_tpl,
			sprintf( esc_html( '%s %s' ), $args['labels']['day'], get_the_date() ),
			$position++
		);
	} elseif ( is_month() ) {
		$items[] = sprintf(
			$item_text_tpl,
			sprintf( esc_html( '%s %s' ), $args['labels']['month'], get_the_date( 'F Y' ) ),
			$position++
		);
	} elseif ( is_year() ) {
		$items[] = sprintf(
			$item_text_tpl,
			sprintf( esc_html( '%s %s' ), $args['labels']['year'], get_the_date( 'Y' ) ),
			$position++
		);
	} else {
		$items[] = sprintf(
			$item_text_tpl,
			$args['labels']['archive'],
			$position++
		);
	}

	// phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
	echo trim( $args['before'] ) . implode( $args['separator'], $items ) . trim( $args['after'] );
}

/**
 * Searches for term parents' IDs of hierarchical taxonomies, including current term.
 * This function is similar to the WordPress function get_category_parents() but handles any type of taxonomy.
 * Modified from Hybrid Framework
 *
 * @param int|string    $term_id  The term ID.
 * @param object|string $taxonomy The taxonomy of the term whose parents we want.
 *
 * @return array Array of parent terms' IDs.
 */
function sober_get_term_parents( $term_id = '', $taxonomy = 'category' ) {
	// Set up some default arrays.
	$list = array();

	// If no term ID or taxonomy is given, return an empty array.
	if ( empty( $term_id ) || empty( $taxonomy ) ) {
		return $list;
	}

	do {
		$list[] = $term_id;

		// Get next parent term.
		$term    = get_term( $term_id, $taxonomy );
		$term_id = $term->parent;
	} while ( $term_id );

	// Reverse the array to put them in the proper order for the trail.
	$list = array_reverse( $list );
	array_pop( $list );

	return $list;
}

/**
 * Gets parent posts' IDs of any post type, include current post
 * Modified from Hybrid Framework
 *
 * @param int|string $post_id ID of the post whose parents we want.
 *
 * @return array Array of parent posts' IDs.
 */
function sober_get_post_parents( $post_id = '' ) {
	// Set up some default array.
	$list = array();

	// If no post ID is given, return an empty array.
	if ( empty( $post_id ) ) {
		return $list;
	}

	do {
		$list[] = $post_id;

		// Get next parent post.
		$post    = get_post( $post_id );
		$post_id = $post->post_parent;
	} while ( $post_id );

	// Reverse the array to put them in the proper order for the trail.
	$list = array_reverse( $list );
	array_pop( $list );

	return $list;
}
